/*******************************************************************************
*
*	Filename		:	FCBioFunc.h
*	Description		:	BioEngine and Database definition
*
*	Company			:	ATMEL-Grenoble
*	Project			:	FingerChip
*	Authors			:	AC	Alain Chambron
*						EV	Emmanuel Vitte
*	Platform		:	independant
*	Language		:	C ANSI
*	Operating System:	independant
*
*	History
*	20-AUG-2003 AC	:	creation
*
*	Copyright (c)2001-2003  All rights reserved
******************************************************************************/

#ifndef __FCBIOFUNC_H__
#define __FCBIOFUNC_H__

#include "FC_Error.h"
#include "FCPublicStruct.h"

#define CAPTURE_CAPS 			0x00000001
#define ENROLLMENT_CAPS			0x00000002
#define VERIFICATION_CAPS	 	0x00000004
#define IDENTIFICATION_CAPS 	0x00000008
#define DATABASE_CAPS	 		0x00000010

typedef struct _t_fc_caps
{
	short			versionMajor ;
	short			versionMinor ;
	char			deviceName[20] ;
	unsigned long	deviceCaps ;
} t_FC_Caps ;

typedef struct _t_fc_biorecord
{
	char			UserName[23] ;
	unsigned char	Finger ;
	unsigned char	BioData[256] ;
} t_FC_BioRecord ;

typedef ErrCode (* t_OpenFunc)( t_FC_Caps *pCaps ) ;
typedef ErrCode (* t_CloseFunc)() ;
typedef ErrCode (* t_StopFunc)() ;
typedef ErrCode (* t_EnrollStartFunc)( unsigned long Length, unsigned char *pBuffer ) ;
typedef ErrCode (* t_EnrollStepFunc)( t_FC_Img *pData, t_FC_ImageInfo *pInfo, char *msg ) ;
typedef ErrCode (* t_EnrollStopFunc)() ;
typedef ErrCode (* t_VerifyFunc)( unsigned long ulSize, unsigned char *pBioData, t_FC_Img *pData, t_FC_ImageInfo *pInfo ) ;
typedef ErrCode (* t_VerifyStopFunc)() ;
typedef ErrCode (* t_IdentifyStartFunc)( unsigned long ulParam, unsigned long *ulSize, unsigned char *pBioData, t_FC_Img *pData, t_FC_ImageInfo *pInfo ) ;
typedef ErrCode (* t_IdentifyStepFunc)( unsigned long *ulSize, unsigned char *pBioData ) ;
typedef ErrCode (* t_IdentifyStopFunc)() ;

// Database specific:

typedef ErrCode (* t_GetRecordFunc)( unsigned long *Length, unsigned char *pRecord ) ;
typedef ErrCode (* t_RemoveFunc)( unsigned long Length, unsigned char *pRecord ) ;
typedef ErrCode (* t_AddRecordFunc)( unsigned long Length, unsigned char *pRecord ) ;
typedef ErrCode (* t_FetchRecordFunc)( unsigned long Length, unsigned char *pRecord ) ;


// Function prototypes:

ErrCode Open( t_FC_Caps *pCaps ) ;
ErrCode Close() ;

// database specific functions

ErrCode GetFirstRecord( unsigned long *Length, unsigned char *pRecord ) ;
ErrCode GetNextRecord( unsigned long *Length, unsigned char *pRecord ) ;
ErrCode FindRecord( unsigned long Length, unsigned char *pRecord ) ;
ErrCode RemoveRecord( unsigned long Length, unsigned char *pRecord ) ;
ErrCode AddRecord( unsigned long Length, unsigned char *pRecord ) ;

// bioengine specific functions

ErrCode EnrollStart( unsigned long Length, unsigned char *pBuffer ) ;
ErrCode EnrollStep( t_FC_Img *pData, t_FC_ImageInfo *pInfo, char *msg ) ;
ErrCode	EnrollStop() ;
ErrCode Verify( unsigned long ulSize, unsigned char *pBioData, t_FC_Img *pData, t_FC_ImageInfo *pInfo ) ;
ErrCode VerifyStop() ;
ErrCode IdentifyStart ( unsigned long ulParam, unsigned long *ulSize, unsigned char *pBioData, t_FC_Img *pData, t_FC_ImageInfo *pInfo );
ErrCode IdentifyStep ( unsigned long *ulSize, unsigned char *pBioData );
ErrCode IdentifyStop() ;

#endif // __FCBIOFUNC_H__
